#
# spec file for package perl-File-LibMagic
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-File-LibMagic
Version:        1.23
Release:        1.18
%define cpan_name File-LibMagic
Summary:        Determine MIME types of data or files using libmagic
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DR/DROLSKY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Config::AutoConf)
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.96
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  file-devel
BuildRequires:  zlib-devel
# MANUAL END

%description
The 'File::LibMagic' module is a simple perl interface to libmagic from the
file package (version 4.x or 5.x). You will need both the library
(_libmagic.so_) and the header file (_magic.h_) to build this Perl module.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc azure-pipelines.yml Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md
%license LICENSE

%changelog
* Sun Aug 30 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.23
  see /usr/share/doc/packages/perl-File-LibMagic/Changes
  1.23     2020-08-28
  - Fixed a bug with the Makefile.PL that caused every call to "make" to
    recompile the object file for the package's XS code. Reported by Kent
    Fredric. GH #28.
* Mon Apr 27 2020 <timueller+perl@suse.de>
- updated to 1.22
  see /usr/share/doc/packages/perl-File-LibMagic/Changes
  1.22     2020-04-26
  - This is a stable release with the same changes as 1.21. See the change logs
    for 1.17 and 1.21 for details of what's new.
  1.21     2020-04-04 (TRIAL RELEASE)
  - Add two class methods that provide introspection on the available limit
    processing parameters, max_param_constant() and
    limit_key_is_supported(). Based on a PR from Paul Wise. GH #24.
  1.20     2020-03-28 (TRIAL RELEASE)
  - Fix one last test that assumed a limit parameter was available. Reported by
    Slaven Rezić. GH #22.
  1.19     2020-03-28 (TRIAL RELEASE)
  - Fix tests that still mistakenly assumed that all limit parameter constants
    should be exported by File::LibMagic. Reported by Slaven Rezić. GH #22.
  1.18     2020-03-28 (TRIAL RELEASE)
  - Not all versions of libmagic support setting processing limits, and those
    that do may not support all the limit parameters that the most recent
    version supports. This release fixes compilation and runtime issues that
    would occur with older libmagic versions that don't support the same options
    as the version I have installed locally. Reported by Slaven Rezić. GH #22.
  1.17     2020-03-28 (TRIAL RELEASE)
  - Switched to using GitHub issues.
  - Removed embedded copy of Config::AutoConf from distro. Instead this is now a
    configure phase prereq. Implemented by Paul Wise. GH #19.
  - Moved list of constants in libmagic that we care about to one
    module. Implemented by Paul Wise. GH #20.
  - Add support for setting libmagic processing limits. Implemented by Paul
    Wise. GH #15.
  - Check all libmagic function return values properly and croak on
    failure. Implemented by Paul Wise. GH #21.
* Mon Oct 23 2017 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-File-LibMagic/Changes
  1.16     2017-10-22
  - Added a doc note on installing the required dependencies on Red Hat. RT
    [#110796].
  - Fix tests on macOS. Based on PR #7 from Tom Wyant.
* Wed May 31 2017 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-File-LibMagic/Changes
  1.15     2015-09-19
  - Fix the Makefile.PL so that we don't install the LibMagic.xs and typemap
    files. Based on a patch from Petr Pisar. RT #107081.
  1.14     2015-09-16
  - Fixed handling of extra include dirs passed to Makefile.PL via the -I
    flag. This wasn't working properly in previous releases. Reported by Andy
    Jack. GH #6.
  1.13     2015-07-12
  - Fix failing tests with some versions of libmagic. PR #5 by E. Choroba.
  1.12     2015-03-07
  - The constructor now accepts named params. In addition to a magic_file param,
    it now accepts follow_symlinks and uncompress params. These do what you'd
    expect, tell the object to follow symlinks and/or uncompress files when
    getting info from them. The old single parameter constructor is still
    supported, but is no longer documented.
  - The old APIs are now called "discouraged" rather than "deprecated" in the
    documentation. I have no plan to remove these APIs any time soon or to make
    them warn, so "deprecated" was too strong a word.
  - Changed a test to hopefully skip rather than fail on OpenBSD systems.
  1.11     2015-03-01
  - The info_from_handle() method did not handle binary data correctly, which
    could lead to incorrect results.
  - The info_from_*() methods returned a full mime type with encoding in the
    "mime_type" key rather than just the mime type alone.
  - Allow File::LibMagic->new() to accept an array reference containing multiple
    magic file paths.
* Fri Feb 20 2015 lnussel@suse.de
- updated to 1.10
  * Added yet another OO API to File::LibMagic. This provides a simpler and more
    future-proof API which can be expanded on later. The new methods are
    info_from_string(), info_from_filename(), and info_from_handle(). The latter
    method allows you to get info about an open filehandle. These new methods
    return the description, MIME type, and character encoding in one call. This
    addresses RT #54843 and partially addresses RT #99470.
  * Switched from using Devel::CheckLib to Config::AutoConf with the hope that
    the latter will work with more compilers. Requested by Jens Rehsack. RT
    [#46543].
  * Switched the primary git repo to github
    (https://github.com/autarch/File-LibMagic).
  * A File::LibMagic object would not close one of the handles it might have
    opened, leading to leaks. Reported by Alexander Zaitsev. RT #93512.
* Mon Dec  2 2013 jw@suse.com
- link to removed, the package does not exist in Factory.
- Fixed source url for version 1.00
* Tue Sep  3 2013 jw@suse.com
- update to 1.00, pulled from cpan
* Mon Feb 20 2012 coolo@suse.com
- regenerate with cpanspec
- disable tests as they rely on specific version of libmagic's text
  output
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Jul  2 2010 chris@computersalat.de
- spec mods
  o added header
  o cleanup
* Tue Jun 29 2010 jw@novell.com
- Sorry that 11.2 did not check the RPM-Group. fixed.
* Sat Jun 26 2010 jw@novell.com
- cleaned up spec-file, added example subdir
  My tests show, that this is the best of all. File::MimeInfo::Magic comes second.
  Thanks Christos!
* Sat Jun 26 2010 jw@novell.com
- initial check in, 0.96
  File::Type, File::MMagic, File::MMagic::XS, File::MimeInfo::Magic need some more competition
